<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.0" language="ro" sourcelanguage="en">
  <context>
    <name>AssemblyGui::Workbench</name>
    <message>
      <location filename="../../Workbench.cpp" line="+50"/>
      <source>Assembly</source>
      <translation>Ansamblu</translation>
    </message>
  </context>
  <context>
    <name>CmdAssemblyConstraintAxle</name>
    <message>
      <location filename="../../Command.cpp" line="+42"/>
      <source>Assembly</source>
      <translation>Ansamblu</translation>
    </message>
    <message>
      <location line="+1"/>
      <source>Constraint Axle...</source>
      <translation>Axul de restricție...
</translation>
    </message>
    <message>
      <location line="+1"/>
      <source>set a axle constraint between two objects</source>
      <translation>setează o restricție axială între două obiecte</translation>
    </message>
  </context>
  <context>
    <name>Workbench</name>
    <message>
      <source>Assembly</source>
      <translation type="obsolete">Ansamblu</translation>
    </message>
  </context>
</TS>
